@@ -30,24 +30,10 @@ import java.util.Hashtable;
 import java.util.Map;
 import java.util.Set;
 
-import javax.servlet.Filter;
-import javax.servlet.FilterRegistration;
-import javax.servlet.RequestDispatcher;
-import javax.servlet.Servlet;
-import javax.servlet.ServletContext;
-import javax.servlet.ServletContextAttributeEvent;
-import javax.servlet.ServletContextAttributeListener;
-import javax.servlet.ServletException;
-import javax.servlet.ServletRegistration;
-import javax.servlet.ServletRegistration.Dynamic;
-import javax.servlet.SessionCookieConfig;
-import javax.servlet.SessionTrackingMode;
-import javax.servlet.descriptor.JspConfigDescriptor;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
-
 import org.apache.felix.http.base.internal.HttpConfig;
 import org.apache.felix.http.base.internal.handler.ListenerHandler;
+import org.apache.felix.http.base.internal.jakartawrappers.ServletRequestWrapper;
+import org.apache.felix.http.base.internal.jakartawrappers.ServletResponseWrapper;
 import org.apache.felix.http.base.internal.registry.EventListenerRegistry;
 import org.apache.felix.http.base.internal.registry.HandlerRegistry;
 import org.apache.felix.http.base.internal.registry.PerContextHandlerRegistry;
@@ -61,6 +47,22 @@ import org.mockito.Mockito;
 import org.osgi.framework.Bundle;
 import org.osgi.service.http.HttpContext;
 
+import jakarta.servlet.Filter;
+import jakarta.servlet.FilterRegistration;
+import jakarta.servlet.RequestDispatcher;
+import jakarta.servlet.Servlet;
+import jakarta.servlet.ServletContext;
+import jakarta.servlet.ServletContextAttributeEvent;
+import jakarta.servlet.ServletContextAttributeListener;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.ServletRegistration;
+import jakarta.servlet.ServletRegistration.Dynamic;
+import jakarta.servlet.SessionCookieConfig;
+import jakarta.servlet.SessionTrackingMode;
+import jakarta.servlet.descriptor.JspConfigDescriptor;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
+
 public class ServletContextImplTest
 {
     private static class AttributeListener implements ServletContextAttributeListener
@@ -457,43 +459,36 @@ public class ServletContextImplTest
 
         @Override
         public Dynamic addJspFile(String servletName, String jspFile) {
-            // TODO Auto-generated method stub
             return null;
         }
 
         @Override
         public int getSessionTimeout() {
-            // TODO Auto-generated method stub
             return 0;
         }
 
         @Override
         public void setSessionTimeout(int sessionTimeout) {
-            // TODO Auto-generated method stub
 
         }
 
         @Override
         public String getRequestCharacterEncoding() {
-            // TODO Auto-generated method stub
             return null;
         }
 
         @Override
         public void setRequestCharacterEncoding(String encoding) {
-            // TODO Auto-generated method stub
 
         }
 
         @Override
         public String getResponseCharacterEncoding() {
-            // TODO Auto-generated method stub
             return null;
         }
 
         @Override
         public void setResponseCharacterEncoding(String encoding) {
-            // TODO Auto-generated method stub
 
         }
     }
@@ -516,7 +511,7 @@ public class ServletContextImplTest
         contextRegistry = reg.getRegistry(HttpServiceFactory.HTTP_SERVICE_CONTEXT_SERVICE_ID);
         final EventListenerRegistry eventReg = contextRegistry.getEventListenerRegistry();
         final ListenerInfo info = Mockito.mock(ListenerInfo.class);
-        when(info.getListenerTypes()).thenReturn(new String[] {ServletContextAttributeListener.class.getName()});
+        when(info.getDTOListenerTypes()).thenReturn(new String[] {ServletContextAttributeListener.class.getName()});
         when(info.isListenerType(ServletContextAttributeListener.class.getName())).thenReturn(true);
         final ListenerHandler handler = Mockito.mock(ListenerHandler.class);
         when(handler.getListenerInfo()).thenReturn(info);
@@ -888,13 +883,15 @@ public class ServletContextImplTest
     @Test
     public void testHandleSecurity() throws Exception
     {
-        HttpServletRequest req = Mockito.mock(HttpServletRequest.class);
-        HttpServletResponse res = Mockito.mock(HttpServletResponse.class);
+        javax.servlet.http.HttpServletRequest req = Mockito.mock(javax.servlet.http.HttpServletRequest.class);
+        javax.servlet.http.HttpServletResponse res = Mockito.mock(javax.servlet.http.HttpServletResponse.class);
 
         Mockito.when(this.httpContext.handleSecurity(req, res)).thenReturn(true);
-        Assert.assertTrue(this.context.handleSecurity(req, res));
+        Assert.assertTrue(this.context.handleSecurity((HttpServletRequest)ServletRequestWrapper.getWrapper(req),
+                (HttpServletResponse)ServletResponseWrapper.getWrapper(res)));
 
         Mockito.when(this.httpContext.handleSecurity(req, res)).thenReturn(false);
-        Assert.assertFalse(this.context.handleSecurity(req, res));
+        Assert.assertFalse(this.context.handleSecurity((HttpServletRequest)ServletRequestWrapper.getWrapper(req),
+                (HttpServletResponse)ServletResponseWrapper.getWrapper(res)));
     }
 }
